Welcome — Python XMP Toolkit v1.0b3 documentation

### Navigation

- index
- modules |
- next |
- Python XMP Toolkit v1.0b3 documentation »

# Welcome

Python AVM Library is a library for working with Astronomy Visualization Metadata in the XMP format.

Authors:
  - Amit Kapadia <akapadia@eso.org>
  - Lars Holm Nielsen <lnielsen@eso.org>

# Documentation

- Introduction
  - Feature Overview
  - What is AVM?
- Installation
  - Requirements
  - Python AVM Library
  - Python XMP Toolkit
  - Exempi
  - Mac OS X
  - Windows
- Using Python AVM Library
  - Method 1: Read AVM
  - Method 2: Read/Write AVM
  - Further Examples
- Reference
  - AVM Toolkit
    - Exceptions
    - Core Module
    - Utils Module
    - Data Types
- Developers
  - Overview of Source Distribution
  - Documentation
  - Packaging a Distribution
  - Running Tests
  - Distribution Configuration
  - References for Developers
- Appendix
  - Resources
  - Glossary
  - TODO list
  - License
  - Changes

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- modules |
- next |
- Python XMP Toolkit v1.0b3 documentation »